@@ -1,8 +1,9 @@
 // Copyright (c) NetXS Group.
 // Licensed under the MIT license.
 
-#ifndef NETXS_APP_CALC_HPP
-#define NETXS_APP_CALC_HPP
+#pragma once
+
+#include "../desktopio/application.hpp"
 
 namespace netxs::events::userland
 {
@@ -26,7 +27,7 @@ namespace netxs::events::userland
     };
 }
 
-namespace netxs::console
+namespace netxs::ui
 {
     // console: Template modules for the base class behavior extension.
     namespace pro
@@ -92,7 +93,7 @@ namespace netxs::console
             cell_highlight(base& boss)
                 : skill{ boss }
             {
-                boss.SUBMIT_T(tier::release, e2::postrender, memo, parent_canvas)
+                boss.SUBMIT(tier::release, e2::postrender, parent_canvas, memo)
                 {
                     auto full = parent_canvas.full();
                     auto view = parent_canvas.view();
@@ -119,7 +120,7 @@ namespace netxs::console
                         }
                     });
                 };
-                boss.SUBMIT_T(tier::release, hids::events::mouse::button::click::left, memo, gear)
+                boss.SUBMIT(tier::release, hids::events::mouse::button::click::left, gear, memo)
                 {
                     auto& item = items.take(gear);
                     if (item.region.size)
@@ -129,7 +130,7 @@ namespace netxs::console
                     }
                     recalc();
                 };
-                boss.SUBMIT_T(tier::release, hids::events::mouse::button::dblclick::left, memo, gear)
+                boss.SUBMIT(tier::release, hids::events::mouse::button::dblclick::left, gear, memo)
                 {
                     auto& item = items.take(gear);
                     auto area = boss.size();
@@ -139,16 +140,16 @@ namespace netxs::console
                     recalc();
                     gear.dismiss();
                 };
-                boss.SUBMIT_T(tier::general, hids::events::die, memo, gear)
+                boss.SUBMIT(tier::general, hids::events::die, gear, memo)
                 {
                     recalc();
                     boss.deface();
                 };
-                boss.SUBMIT_T(tier::release, hids::events::notify::mouse::enter, memo, gear)
+                boss.SUBMIT(tier::release, hids::events::notify::mouse::enter, gear, memo)
                 {
                     items.add(gear);
                 };
-                boss.SUBMIT_T(tier::release, hids::events::notify::mouse::leave, memo, gear)
+                boss.SUBMIT(tier::release, hids::events::notify::mouse::leave, gear, memo)
                 {
                     auto& item = items.take(gear);
                     if (item.region.size)
@@ -158,7 +159,7 @@ namespace netxs::console
                     else items.del(gear);
                     recalc();
                 };
-                engage<sysmouse::left>();
+                engage<hids::buttons::left>();
             }
             void recalc()
             {
@@ -194,23 +195,23 @@ namespace netxs::console
                 boss.SIGNAL(tier::release, e2::data::text, data);
             }
             // pro::cell_highlight: Configuring the mouse button to operate.
-            template<sysmouse::bttns BUTTON>
+            template<hids::buttons Button>
             void engage()
             {
-                boss.SIGNAL(tier::release, e2::form::draggable::_<BUTTON>, true);
-                boss.SUBMIT_T(tier::release, hids::events::mouse::move, memo, gear)
+                boss.SIGNAL(tier::release, e2::form::draggable::_<Button>, true);
+                boss.SUBMIT(tier::release, hids::events::mouse::move, gear, memo)
                 {
                     items.take(gear).calc(boss, gear.coord);
                     boss.base::deface();
                 };
-                boss.SUBMIT_T(tier::release, e2::form::drag::start::_<BUTTON>, memo, gear)
+                boss.SUBMIT(tier::release, e2::form::drag::start::_<Button>, gear, memo)
                 {
                     if (items.take(gear).grab(gear.coord, gear.meta(hids::anyCtrl)))
                     {
                         gear.dismiss();
                     }
                 };
-                boss.SUBMIT_T(tier::release, e2::form::drag::pull::_<BUTTON>, memo, gear)
+                boss.SUBMIT(tier::release, e2::form::drag::pull::_<Button>, gear, memo)
                 {
                     if (items.take(gear).drag(gear.coord))
                     {
@@ -218,12 +219,12 @@ namespace netxs::console
                         gear.dismiss();
                     }
                 };
-                boss.SUBMIT_T(tier::release, e2::form::drag::cancel::_<BUTTON>, memo, gear)
+                boss.SUBMIT(tier::release, e2::form::drag::cancel::_<Button>, gear, memo)
                 {
                     items.take(gear).drop();
                     recalc();
                 };
-                boss.SUBMIT_T(tier::release, e2::form::drag::stop::_<BUTTON>, memo, gear)
+                boss.SUBMIT(tier::release, e2::form::drag::stop::_<Button>, gear, memo)
                 {
                     items.take(gear).drop();
                     recalc();
@@ -312,10 +313,13 @@ namespace netxs::app::calc
             }
             return std::tuple{ cellatix_rows, cellatix_cols, cellatix_text };
         };
-        auto build = [](text cwd, text arg)
+        auto build = [](text cwd, text arg, xml::settings& config, text patch)
         {
-            const static auto c7 = app::shared::c7;
-            const static auto c3 = app::shared::c3;
+            auto highlight_color = skin::color(tone::highlight);
+            auto label_color     = skin::color(tone::label);
+            auto c3 = highlight_color;
+            auto x3 = cell{ c3 }.alpha(0x00);
+            auto c7 = label_color;
 
             auto [cellatix_rows, cellatix_cols, cellatix_text] = get_text();
 
@@ -331,18 +335,19 @@ namespace netxs::app::calc
                       boss.keybd.accept(true);
                       boss.SUBMIT(tier::anycast, e2::form::quit, item)
                       {
-                          boss.base::template riseup<tier::release>(e2::form::quit, item);
+                          boss.RISEUP(tier::release, e2::form::quit, item);
                       };
                       boss.SUBMIT(tier::release, e2::form::upon::vtree::attached, parent)
                       {
                           static auto i = 0; i++;
                           auto title = ansi::jet(bias::right).add("Spreadsheet\n ~/Untitled ", i, ".ods");
-                          boss.base::template riseup<tier::preview>(e2::form::prop::ui::header, title);
+                          boss.RISEUP(tier::preview, e2::form::prop::ui::header, title);
                       };
                   });
+            auto fader = skin::timeout(tone::fader);
             auto object = window->attach(ui::fork::ctor(axis::Y))
                                 ->colors(whitelt, 0);
-                auto menu = object->attach(slot::_1, app::shared::main_menu());
+                auto menu = object->attach(slot::_1, app::shared::menu::demo(config));
                 auto all_rail = object->attach(slot::_2, ui::rail::ctor());
                 auto all_stat = all_rail->attach(ui::fork::ctor(axis::Y))
                                         ->plugin<pro::limit>(twod{ -1,-1 },twod{ 136,102 });
@@ -351,11 +356,11 @@ namespace netxs::app::calc
                             auto func_line = func_body->attach(slot::_1, ui::fork::ctor());
                                 auto fx_sum = func_line->attach(slot::_1, ui::fork::ctor());
                                     auto fx = fx_sum->attach(slot::_1, ui::post::ctor())
-                                                    ->plugin<pro::fader>(c7, c3, 150ms)
+                                                    ->plugin<pro::fader>(c7, c3, fader)
                                                     ->plugin<pro::limit>(twod{ 3,-1 }, twod{ 4,-1 })
                                                     ->upload(ansi::wrp(wrap::off).add(" Fx "));
                                 auto ellipsis = func_line->attach(slot::_2, ui::post::ctor())
-                                                         ->plugin<pro::fader>(c7, c3, 150ms)
+                                                         ->plugin<pro::fader>(c7, c3, fader)
                                                          ->plugin<pro::limit>(twod{ -1,1 }, twod{ 3,-1 })
                                                          ->upload(ansi::wrp(wrap::off).add(" … "));
                             auto body_area = func_body->attach(slot::_2, ui::fork::ctor(axis::Y));
@@ -402,7 +407,7 @@ namespace netxs::app::calc
                                                        .bgc(whitelt).fgc(blackdk).add(" Sheet1 "));
                             auto plus_pad = sheet_plus->attach(slot::_2, ui::fork::ctor());
                                 auto plus = plus_pad->attach(slot::_1, ui::post::ctor())
-                                                    ->plugin<pro::fader>(c7, c3, 150ms)
+                                                    ->plugin<pro::fader>(c7, c3, fader)
                                                     ->plugin<pro::limit>(twod{ 3,-1 }, twod{ 3,-1 })
                                                     ->upload(ansi::wrp(wrap::off).add(" + "));
                                 auto pad = plus_pad->attach(slot::_2, ui::mock::ctor())
@@ -413,6 +418,4 @@ namespace netxs::app::calc
     }
 
     app::shared::initialize builder{ "calc", build };
-}
-
-#endif // NETXS_APP_CALC_HPP
\ No newline at end of file
+}
\ No newline at end of file
