@@ -1,8 +1,7 @@
 // Copyright (c) NetXS Group.
 // Licensed under the MIT license.
 
-#ifndef NETXS_APP_TEST_HPP
-#define NETXS_APP_TEST_HPP
+#pragma once
 
 namespace netxs::events::userland
 {
@@ -414,7 +413,7 @@ namespace netxs::app::test
 
             return topic;
         };
-        auto build = [](text cwd, text arg, xml::settings& config)
+        auto build = [](text cwd, text arg, xml::settings& config, text patch)
         {
             auto topic = get_text();
             auto window = ui::cake::ctor()
@@ -427,13 +426,13 @@ namespace netxs::app::test
                     boss.keybd.accept(true);
                     boss.SUBMIT(tier::anycast, e2::form::quit, item)
                     {
-                        boss.base::template riseup<tier::release>(e2::form::quit, item);
+                        boss.RISEUP(tier::release, e2::form::quit, item);
                     };
                 });
             auto object0 = window->attach(ui::fork::ctor(axis::Y))
                                  ->colors(whitelt, 0xA0db3700);
                 config.cd("/config/test/", "/config/defapp/");
-                auto [menu_block, cover, menu_data] = app::shared::custom_menu(config, {});
+                auto [menu_block, cover, menu_data] = app::shared::menu::create(config, {});
                 auto menu = object0->attach(slot::_1, menu_block);
                 auto test_stat_area = object0->attach(slot::_2, ui::fork::ctor(axis::Y));
                     auto layers = test_stat_area->attach(slot::_1, ui::cake::ctor());
@@ -480,6 +479,4 @@ namespace netxs::app::test
     }
 
     app::shared::initialize builder{ "test", build };
-}
-
-#endif // NETXS_APP_TEST_HPP
\ No newline at end of file
+}
\ No newline at end of file
