@@ -1,8 +1,7 @@
 // Copyright (c) NetXS Group.
 // Licensed under the MIT license.
 
-#ifndef NETXS_APP_TILE_HPP
-#define NETXS_APP_TILE_HPP
+#pragma once
 
 // Tiling limits.
 #define INHERITANCE_LIMIT 30
@@ -18,10 +17,10 @@ namespace netxs::events::userland
     {
         EVENTPACK( tile, netxs::events::userland::root::custom )
         {
-            EVENT_XS( backup, app::tile::backups  ),
-            EVENT_XS( enlist, sptr<console::base> ),
-            EVENT_XS( delist, bool                ),
-            GROUP_XS( ui    , input::hids         ), // Window manager command pack.
+            EVENT_XS( backup, app::tile::backups ),
+            EVENT_XS( enlist, sptr<ui::base>     ),
+            EVENT_XS( delist, bool               ),
+            GROUP_XS( ui    , input::hids        ), // Window manager command pack.
 
             SUBSET_XS( ui )
             {
@@ -85,8 +84,12 @@ namespace netxs::app::tile
                 if (!client) return;
                 auto label = [](auto data_src_sptr, auto header)
                 {
+                    auto highlight_color = skin::color(tone::highlight);
+                    auto c3 = highlight_color;
+                    auto x3 = cell{ c3 }.alpha(0x00);
+
                     return ui::pads::ctor(dent{ 1, 1, 0, 0 }, dent{})
-                        ->plugin<pro::fader>(app::shared::x3, app::shared::c3, 150ms)
+                        ->plugin<pro::fader>(x3, c3, skin::timeout(tone::fader))
                         ->branch(ui::item::ctor(header.empty() ? "- no title -" : header))
                         ->invoke([&](auto& boss)
                         {
@@ -103,7 +106,10 @@ namespace netxs::app::tile
                             };
                             data_src_sptr->SUBMIT_T(tier::preview, e2::form::highlight::any, boss.tracker, state)
                             {
-                                boss.color(state ? 0xFF00ff00 : app::shared::x3.fgc(), app::shared::x3.bgc());
+                                auto highlight_color = skin::color(tone::highlight);
+                                auto c3 = highlight_color;
+                                auto x3 = cell{ c3 }.alpha(0x00);
+                                boss.color(state ? 0xFF00ff00 : x3.fgc(), x3.bgc());
                             };
                             data_src_sptr->SUBMIT_T(tier::release, events::delist, boss.tracker, object)
                             {
@@ -116,6 +122,7 @@ namespace netxs::app::tile
                                 {
                                     auto deed = boss_ptr->bell::template protos<tier::release>(); //todo "template" keyword is required by FreeBSD clang 11.0.1
                                     data_ptr->template signal<tier::release>(deed, gear); //todo "template" keyword is required by gcc
+                                    gear.dismiss();
                                 }
                             };
                             boss.SUBMIT_T_BYVAL(tier::release, e2::form::state::mouse, boss.tracker, active)
@@ -257,6 +264,7 @@ namespace netxs::app::tile
                     ->active()
                     ->invoke([&](auto& boss)
                     {
+                        boss.keybd.active();
                         anycasting(boss);
                         mouse_subs(boss);
 
@@ -397,9 +405,12 @@ namespace netxs::app::tile
         };
         auto empty_pane = []
         {
+            auto menu_black = skin::color(tone::menu_black);
+            auto cC = menu_black;
+
             return ui::park::ctor()
                 ->isroot(true, 2)
-                ->colors(blacklt, app::shared::term_menu_bg)
+                ->colors(cC.fgc(), cC.bgc())
                 ->plugin<pro::limit>(dot_00, -dot_11)
                 ->plugin<pro::focus>()
                 ->invoke([&](auto& boss)
@@ -431,11 +442,14 @@ namespace netxs::app::tile
                     };
                     boss.SUBMIT(tier::release, e2::form::proceed::d_n_d::abort, target)
                     {
+                        auto menu_black = skin::color(tone::menu_black);
+                        auto cC = menu_black;
                         auto count = boss.count();
                         if (count == 1) // Only empty slot available.
                         {
                             //todo unify
-                            boss.back()->color(blacklt, app::shared::term_menu_bg);
+                            boss.back()->color(cC.fgc(), cC.bgc());
+                            boss.deface();
                         }
                     };
                     boss.SUBMIT(tier::release, e2::form::proceed::d_n_d::ask, target)
@@ -443,22 +457,27 @@ namespace netxs::app::tile
                         auto count = boss.count();
                         if (count == 1) // Only empty slot available.
                         {
-                            //todo unify
-                            auto fg = app::shared::c3.fgc();
-                            auto bg = app::shared::c3.bgc();
+                            auto highlight_color = skin::color(tone::highlight);
+                            auto c3 = highlight_color;
+                            auto x3 = cell{ c3 }.alpha(0x00);
+                            auto fg = c3.fgc();
+                            auto bg = c3.bgc();
                             fg.alpha(0x70);
                             bg.alpha(0x70);
                             boss.back()->color(fg, bg);
                             target = boss.This();
+                            boss.deface();
                         }
                     };
                     boss.SUBMIT(tier::release, e2::form::proceed::d_n_d::drop, what)
                     {
+                        auto menu_black = skin::color(tone::menu_black);
+                        auto cC = menu_black;
                         auto count = boss.count();
                         if (count == 1) // Only empty slot available.
                         {
                             //todo unify
-                            boss.back()->color(blacklt, app::shared::term_menu_bg);
+                            boss.back()->color(cC.fgc(), cC.bgc());
                             auto app = app_window(what.header, what.footer, what.object, what.menuid);
                             boss.attach(app);
                             app->SIGNAL(tier::anycast, e2::form::upon::started, app);
@@ -524,7 +543,7 @@ namespace netxs::app::tile
                     };
                     boss.SUBMIT(tier::anycast, app::tile::events::ui::select, gear)
                     {
-                        auto& item =*boss.back();
+                        auto& item = *boss.back();
                         if (item.base::kind() != 1)
                         {
                             //todo unify
@@ -537,7 +556,7 @@ namespace netxs::app::tile
                         }
                         else item.SIGNAL(tier::release, hids::events::upevent::kbannul, gear); // Exclude grips.
                     };
-                    hook oneoff; // One-time return ticket.
+                    subs oneoff; // One-time return ticket.
                     boss.SUBMIT_BYVAL(tier::release, e2::form::maximize, gear)
                     {
                         if (auto boss_ptr = shadow.lock())
@@ -581,6 +600,10 @@ namespace netxs::app::tile
                                             }
                                             oneoff.reset();
                                         };
+                                        fullscreen_item->SUBMIT_T(tier::release, e2::dtor, oneoff, item_ptr)
+                                        {
+                                            oneoff.reset();
+                                        };
                                         boss.base::template riseup<tier::release>(e2::form::proceed::attach, fullscreen_item);
                                         boss.base::reflow();
                                     }
@@ -681,19 +704,16 @@ namespace netxs::app::tile
                                 auto current_default = e2::data::changed.param();
                                 gate.SIGNAL(tier::request, e2::data::changed, current_default);
 
-                                auto& conf_list = app::shared::configs();
-                                auto config = conf_list[current_default];
+                                auto [object, config] = app::shared::create::go(current_default);
 
-                                auto& creator = app::shared::creator(config.type);
-                                auto host = creator(config.cwd, config.param);
-                                auto app = app_window(config.title, "", host, current_default);
+                                auto app = app_window(config.title, "", object, current_default);
                                 gear.remove_from_kb_focus(boss.back()); // Take focus from the empty slot.
                                 boss.attach(app);
 
                                 //todo unify, demo limits
                                 {
                                     insts_count++;
-                                    host->SUBMIT(tier::release, e2::dtor, id)
+                                    object->SUBMIT(tier::release, e2::dtor, id)
                                     {
                                         insts_count--;
                                         log("tile: inst: detached: ", insts_count, " id=", id);
@@ -703,11 +723,10 @@ namespace netxs::app::tile
 
                                 //todo unify
                                 gear.kb_focus_changed = faux;
-                                host->SIGNAL(tier::release, hids::events::upevent::kboffer, gear);
+                                object->SIGNAL(tier::release, hids::events::upevent::kboffer, gear);
                             }
                         }
                     };
-
                     boss.SUBMIT(tier::release, events::backup, empty_slot_list)
                     {
                         if (boss.count())
@@ -770,39 +789,30 @@ namespace netxs::app::tile
             else  // Add application.
             {
                 utf::trim_front(utf8, " ");
-                auto app_id = utf::get_tail(utf8, " ,)");
+                auto app_id = text{ utf::get_tail(utf8, " ,)") };
                 if (app_id.empty()) return place;
 
                 utf::trim_front(utf8, " ,");
                 if (utf8.size() && utf8.front() == ')') utf8.remove_prefix(1); // pop ')';
 
-                auto& conf_list = app::shared::configs();
-                auto iter = conf_list.find(app_id);
-                if (iter == conf_list.end())
-                {
-                    log("tile: application id='", app_id, "' not found");
-                    return place;
-                }
-                auto& config = iter->second;
-                auto& creator = app::shared::creator(config.type);
-                auto host = creator(config.cwd, config.param);
-                auto inst = app_window(config.title, config.footer, host, app_id);
-                if (config.bgcolor)  inst->SIGNAL(tier::anycast, e2::form::prop::colors::bg,   config.bgcolor);
-                if (config.fgcolor)  inst->SIGNAL(tier::anycast, e2::form::prop::colors::fg,   config.fgcolor);
-                if (config.slimmenu) inst->SIGNAL(tier::anycast, e2::form::prop::ui::slimmenu, config.slimmenu);
+                auto [object, config] = app::shared::create::go(app_id);
+                auto inst = app_window(config.title, config.footer, object, app_id);
                 place->attach(inst);
             }
             return place;
         };
-        auto build_inst = [](text cwd, view param) -> sptr<base>
+        auto build_inst = [](text cwd, view param, xml::settings& config, text patch) -> sptr<base>
         {
+            auto menu_white = skin::color(tone::menu_white);
+            auto cB = menu_white;
+
             auto object = ui::fork::ctor(axis::Y)
                         ->plugin<items>();
 
             object->invoke([&](auto& boss)
                 {
                     auto oneoff = std::make_shared<hook>();
-                    auto& conf_list = app::shared::configs();
+                    auto& conf_list = app::shared::get::configs();
                     auto objs_config_ptr = &conf_list;
                     boss.SUBMIT_T_BYVAL(tier::anycast, e2::form::upon::created, *oneoff, gear)
                     {
@@ -812,7 +822,7 @@ namespace netxs::app::tile
                         gate.SIGNAL(tier::request, e2::data::changed, menu_item_id);
                         //todo unify
                         auto& config = objs_config[menu_item_id];
-                        if (config.type == app::shared::type_Region) // Reset the currently selected application to the previous one.
+                        if (config.type == menuitem_t::type_Group) // Reset the currently selected application to the previous one.
                         {
                             gate.SIGNAL(tier::preview, e2::data::changed, menu_item_id); // Get previous default;
                             gate.SIGNAL(tier::release, e2::data::changed, menu_item_id); // Set current  default;
@@ -821,15 +831,18 @@ namespace netxs::app::tile
                     };
                 });
 
-            object->attach(slot::_1, app::shared::custom_menu(true,
-                    app::shared::menu_list_type
+            config.cd("/config/tile/", "/config/defapp/");
+
+            using namespace app::shared;
+            auto [menu_block, cover, menu_data] = menu::create(config,
+                    menu::list
                     {
                         //  Green                                  ?Even    Red
                         // ┌────┐  ┌────┐  ┌─┬──┐  ┌────┐  ┌─┬──┐  ┌─┬──┐  ┌────┐  // ┌─┐  ┌─┬─┐  ┌─┬─┐  ┌─┬─┐  
                         // │Exec│  ├─┐  │  │ H  │  ├ V ─┤  │Swap│  │Fair│  │Shut│  // ├─┤  └─┴─┘  └<┴>┘  └>┴<┘  
                         // └────┘  └─┴──┘  └─┴──┘  └────┘  └─┴──┘  └─┴──┘  └────┘  // └─┘                       
-                        { true,"  ┐└  ", " Maximize/restore active pane ", //  ─┐  ", //"  ▀█  ",
-                        [](ui::pads& boss)
+                        { std::make_shared<menu::item>(menu::item{ menu::item::type::Command, true, 0, std::vector<menu::item::look>{ { .label = "  ┐└  ", .notes = " Maximize/restore active pane " } }}),
+                        [](ui::pads& boss, auto& item)
                         {
                             boss.SUBMIT(tier::release, hids::events::mouse::button::click::left, gear)
                             {
@@ -838,8 +851,8 @@ namespace netxs::app::tile
                                 gear.dismiss(true);
                             };
                         }},
-                        { true, "  +  ", " Create and run a new app in active panes ",
-                        [](ui::pads& boss)
+                        { std::make_shared<menu::item>(menu::item{ menu::item::type::Command, true, 0, std::vector<menu::item::look>{ { .label = "  +  ", .notes = " Create and run a new app in active panes " } }}),
+                        [](ui::pads& boss, auto& item)
                         {
                             boss.SUBMIT(tier::release, hids::events::mouse::button::click::left, gear)
                             {
@@ -847,8 +860,8 @@ namespace netxs::app::tile
                                 gear.dismiss(true);
                             };
                         }},
-                        { true, " ::: ", " Select all panes ",
-                        [](ui::pads& boss)
+                        { std::make_shared<menu::item>(menu::item{ menu::item::type::Command, true, 0, std::vector<menu::item::look>{ { .label = " ::: ", .notes = " Select all panes " } }}),
+                        [](ui::pads& boss, auto& item)
                         {
                             boss.SUBMIT(tier::release, hids::events::mouse::button::click::left, gear)
                             {
@@ -856,8 +869,8 @@ namespace netxs::app::tile
                                 gear.dismiss(true);
                             };
                         }},
-                        { true, "  │  ", " Split active panes horizontally ", // "  ║  ", - VGA Linux console doesn't support unicode glyphs
-                        [](ui::pads& boss)
+                        { std::make_shared<menu::item>(menu::item{ menu::item::type::Command, true, 0, std::vector<menu::item::look>{ { .label = "  │  ", .notes = " Split active panes horizontally " } }}),
+                        [](ui::pads& boss, auto& item)
                         {
                             boss.SUBMIT(tier::release, hids::events::mouse::button::click::left, gear)
                             {
@@ -865,8 +878,8 @@ namespace netxs::app::tile
                                 gear.dismiss(true);
                             };
                         }},
-                        { true, " ── ", " Split active panes vertically ", // " ══ ", - VGA Linux console doesn't support unicode glyphs
-                        [](ui::pads& boss)
+                        { std::make_shared<menu::item>(menu::item{ menu::item::type::Command, true, 0, std::vector<menu::item::look>{ { .label = " ── ", .notes = " Split active panes vertically " } }}),
+                        [](ui::pads& boss, auto& item)
                         {
                             boss.SUBMIT(tier::release, hids::events::mouse::button::click::left, gear)
                             {
@@ -874,8 +887,8 @@ namespace netxs::app::tile
                                 gear.dismiss(true);
                             };
                         }},
-                        { true, "  ┌┘  ", " Change split orientation ",
-                        [](ui::pads& boss)
+                        { std::make_shared<menu::item>(menu::item{ menu::item::type::Command, true, 0, std::vector<menu::item::look>{ { .label = "  ┌┘  ", .notes = " Change split orientation " } }}),
+                        [](ui::pads& boss, auto& item)
                         {
                             boss.SUBMIT(tier::release, hids::events::mouse::button::click::left, gear)
                             {
@@ -883,8 +896,8 @@ namespace netxs::app::tile
                                 gear.dismiss(true);
                             };
                         }},
-                        { true, " <-> ", " Swap two or more panes ",
-                        [](ui::pads& boss)
+                        { std::make_shared<menu::item>(menu::item{ menu::item::type::Command, true, 0, std::vector<menu::item::look>{ { .label = " <-> ", .notes = " Swap two or more panes " } }}),
+                        [](ui::pads& boss, auto& item)
                         {
                             boss.SUBMIT(tier::release, hids::events::mouse::button::click::left, gear)
                             {
@@ -892,8 +905,8 @@ namespace netxs::app::tile
                                 gear.dismiss(true);
                             };
                         }},
-                        { true, " >|< ", " Equalize split ratio ",
-                        [](ui::pads& boss)
+                        { std::make_shared<menu::item>(menu::item{ menu::item::type::Command, true, 0, std::vector<menu::item::look>{ { .label = " >|< ", .notes = " Equalize split ratio " } }}),
+                        [](ui::pads& boss, auto& item)
                         {
                             boss.SUBMIT(tier::release, hids::events::mouse::button::click::left, gear)
                             {
@@ -901,8 +914,8 @@ namespace netxs::app::tile
                                 gear.dismiss(true);
                             };
                         }},
-                        { true, "  ×  ", " Close active app or remove pane if there is no running app ",
-                        [](ui::pads& boss)
+                        { std::make_shared<menu::item>(menu::item{ menu::item::type::Command, true, 0, std::vector<menu::item::look>{ { .label = "  ×  ", .notes = " Close active app or remove pane if there is no running app " } }}),
+                        [](ui::pads& boss, auto& item)
                         {
                             boss.SUBMIT(tier::release, hids::events::mouse::button::click::left, gear)
                             {
@@ -910,20 +923,31 @@ namespace netxs::app::tile
                                 gear.dismiss(true);
                             };
                         }},
-                    }))
-                    ->colors(whitelt, app::shared::term_menu_bg)
-                    ->plugin<pro::focus>()
-                    ->plugin<pro::track>()
-                    ->plugin<pro::acryl>()
-                    ->invoke([](auto& boss)
-                    {
-                        boss.keybd.active();
-                        boss.SUBMIT(tier::anycast, e2::form::quit, item)
-                        {
-                            boss.base::template riseup<tier::release>(e2::form::quit, item);
-                        };
                     });
-
+            object->attach(slot::_1, menu_block)
+                  ->plugin<pro::focus>()
+                  ->invoke([](auto& boss)
+                  {
+                      boss.keybd.active();
+                      boss.SUBMIT(tier::anycast, e2::form::quit, item)
+                      {
+                          boss.base::template riseup<tier::release>(e2::form::quit, item);
+                      };
+                  });
+            menu_data->colors(cB.fgc(), cB.bgc())
+                     ->plugin<pro::track>()
+                     ->plugin<pro::acryl>();
+            auto menu_id = menu_block->id;
+            cover->invoke([&](auto& boss)
+            {
+                auto bar = cell{ "▀"sv }.link(menu_id);
+                boss.SUBMIT_BYVAL(tier::release, e2::render::any, parent_canvas)
+                {
+                    auto menu_white = skin::color(tone::menu_white);
+                    auto fgc = menu_white.bgc();
+                    parent_canvas.fill([&](cell& c) { c.fgc(fgc).txt(bar).link(bar); });
+                };
+            });
             if (cwd.size())
             {
                 auto err = std::error_code{};
@@ -1036,7 +1060,5 @@ namespace netxs::app::tile
         };
     }
 
-    app::shared::initialize builder{ app::shared::type_Group, build_inst };
-}
-
-#endif // NETXS_APP_TILE_HPP
\ No newline at end of file
+    app::shared::initialize builder{ menuitem_t::type_Group, build_inst };
+}
\ No newline at end of file
